@@ -9,7 +9,7 @@ use Getopt::Kingpin::Commands;
 use File::Basename;
 use Carp;
 
-our $VERSION = "0.05";
+our $VERSION = "0.06";
 
 use overload (
     '""' => sub {$_[0]->name},
@@ -120,6 +120,10 @@ sub _parse {
     my $self = shift;
     my @argv = @_;
 
+    if (defined $self->parent) {
+        $self->flags->unshift($self->parent->flags->values);
+    }
+
     my $required_but_not_found = {
         map {$_->name => $_} grep {$_->_required} $self->flags->values,
     };
